# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserTwoStepVerificationSetPassword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserTwoStepVerificationSetPassword.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n(UserTwoStepVerificationSetPassword.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xeb\x01\n\"UserTwoStepVerificationSetPassword\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12\x16\n\x0erecovery_email\x18\x04 \x01(\t\x12\x14\n\x0cquestion_one\x18\x05 \x01(\t\x12\x12\n\nanswer_one\x18\x06 \x01(\t\x12\x14\n\x0cquestion_two\x18\x07 \x01(\t\x12\x12\n\nanswer_two\x18\x08 \x01(\t\x12\x0c\n\x04hint\x18\t \x01(\t\"r\n*UserTwoStepVerificationSetPasswordResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12!\n\x19unconfirmed_email_pattern\x18\x02 \x01(\tB9\n\x0enet.iGap.protoB\'ProtoUserTwoStepVerificationSetPasswordb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERTWOSTEPVERIFICATIONSETPASSWORD = _descriptor.Descriptor(
  name='UserTwoStepVerificationSetPassword',
  full_name='proto.UserTwoStepVerificationSetPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserTwoStepVerificationSetPassword.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='old_password', full_name='proto.UserTwoStepVerificationSetPassword.old_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='proto.UserTwoStepVerificationSetPassword.new_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recovery_email', full_name='proto.UserTwoStepVerificationSetPassword.recovery_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_one', full_name='proto.UserTwoStepVerificationSetPassword.question_one', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_one', full_name='proto.UserTwoStepVerificationSetPassword.answer_one', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_two', full_name='proto.UserTwoStepVerificationSetPassword.question_two', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='answer_two', full_name='proto.UserTwoStepVerificationSetPassword.answer_two', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hint', full_name='proto.UserTwoStepVerificationSetPassword.hint', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=318,
)


_USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='UserTwoStepVerificationSetPasswordResponse',
  full_name='proto.UserTwoStepVerificationSetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserTwoStepVerificationSetPasswordResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_email_pattern', full_name='proto.UserTwoStepVerificationSetPasswordResponse.unconfirmed_email_pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=434,
)

_USERTWOSTEPVERIFICATIONSETPASSWORD.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationSetPassword'] = _USERTWOSTEPVERIFICATIONSETPASSWORD
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationSetPasswordResponse'] = _USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE

UserTwoStepVerificationSetPassword = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationSetPassword', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONSETPASSWORD,
  __module__ = 'UserTwoStepVerificationSetPassword_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationSetPassword)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationSetPassword)

UserTwoStepVerificationSetPasswordResponse = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationSetPasswordResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONSETPASSWORDRESPONSE,
  __module__ = 'UserTwoStepVerificationSetPassword_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationSetPasswordResponse)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationSetPasswordResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\'ProtoUserTwoStepVerificationSetPassword'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingOffer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingOffer.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14SignalingOffer.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xda\x01\n\x0eSignalingOffer\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x16\n\x0e\x63\x61lled_user_id\x18\x02 \x01(\x04\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x12\n\ncaller_sdp\x18\x04 \x01(\t\"Q\n\x04Type\x12\x11\n\rVOICE_CALLING\x10\x00\x12\x11\n\rVIDEO_CALLING\x10\x01\x12\x12\n\x0eSCREEN_SHARING\x10\x02\x12\x0f\n\x0bSECRET_CHAT\x10\x03\"\x91\x01\n\x16SignalingOfferResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x16\n\x0e\x63\x61ller_user_id\x18\x02 \x01(\x04\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x12\n\ncaller_sdp\x18\x04 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoSignalingOfferb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGOFFER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.SignalingOffer.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALLING', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_CALLING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCREEN_SHARING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECRET_CHAT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=200,
  serialized_end=281,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGOFFER_TYPE)


_SIGNALINGOFFER = _descriptor.Descriptor(
  name='SignalingOffer',
  full_name='proto.SignalingOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingOffer.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='called_user_id', full_name='proto.SignalingOffer.called_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingOffer.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_sdp', full_name='proto.SignalingOffer.caller_sdp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGOFFER_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=281,
)


_SIGNALINGOFFERRESPONSE = _descriptor.Descriptor(
  name='SignalingOfferResponse',
  full_name='proto.SignalingOfferResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingOfferResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_user_id', full_name='proto.SignalingOfferResponse.caller_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingOfferResponse.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='caller_sdp', full_name='proto.SignalingOfferResponse.caller_sdp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=429,
)

_SIGNALINGOFFER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGOFFER.fields_by_name['type'].enum_type = _SIGNALINGOFFER_TYPE
_SIGNALINGOFFER_TYPE.containing_type = _SIGNALINGOFFER
_SIGNALINGOFFERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGOFFERRESPONSE.fields_by_name['type'].enum_type = _SIGNALINGOFFER_TYPE
DESCRIPTOR.message_types_by_name['SignalingOffer'] = _SIGNALINGOFFER
DESCRIPTOR.message_types_by_name['SignalingOfferResponse'] = _SIGNALINGOFFERRESPONSE

SignalingOffer = _reflection.GeneratedProtocolMessageType('SignalingOffer', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGOFFER,
  __module__ = 'SignalingOffer_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingOffer)
  ))
_sym_db.RegisterMessage(SignalingOffer)

SignalingOfferResponse = _reflection.GeneratedProtocolMessageType('SignalingOfferResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGOFFERRESPONSE,
  __module__ = 'SignalingOffer_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingOfferResponse)
  ))
_sym_db.RegisterMessage(SignalingOfferResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoSignalingOffer'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupGetMemberList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import GroupAddAdmin_pb2 as GroupAddAdmin__pb2
from ighap_bot.proto import GroupChangeMemberRights_pb2 as GroupChangeMemberRights__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GroupGetMemberList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18GroupGetMemberList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x13GroupAddAdmin.proto\x1a\x1dGroupChangeMemberRights.proto\"\xe5\x01\n\x12GroupGetMemberList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x39\n\x0b\x66ilter_role\x18\x03 \x01(\x0e\x32$.proto.GroupGetMemberList.FilterRole\x12%\n\npagination\x18\x04 \x01(\x0b\x32\x11.proto.Pagination\";\n\nFilterRole\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MEMBER\x10\x01\x12\r\n\tMODERATOR\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"\xb3\x02\n\x1aGroupGetMemberListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x38\n\x06member\x18\x02 \x03(\x0b\x32(.proto.GroupGetMemberListResponse.Member\x1a\xb7\x01\n\x06Member\x12\x0e\n\x06userId\x18\x01 \x01(\x04\x12#\n\x04role\x18\x02 \x01(\x0e\x32\x15.proto.GroupRoom.Role\x12\x35\n\x0b\x61\x64minRights\x18\x03 \x01(\x0b\x32 .proto.GroupAddAdmin.AdminRights\x12\x41\n\x0cmemberRights\x18\x04 \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRightsB)\n\x0enet.iGap.protoB\x17ProtoGroupGetMemberListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,GroupAddAdmin__pb2.DESCRIPTOR,GroupChangeMemberRights__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_GROUPGETMEMBERLIST_FILTERROLE = _descriptor.EnumDescriptor(
  name='FilterRole',
  full_name='proto.GroupGetMemberList.FilterRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=303,
  serialized_end=362,
)
_sym_db.RegisterEnumDescriptor(_GROUPGETMEMBERLIST_FILTERROLE)


_GROUPGETMEMBERLIST = _descriptor.Descriptor(
  name='GroupGetMemberList',
  full_name='proto.GroupGetMemberList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GroupGetMemberList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.GroupGetMemberList.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_role', full_name='proto.GroupGetMemberList.filter_role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.GroupGetMemberList.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPGETMEMBERLIST_FILTERROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=362,
)


_GROUPGETMEMBERLISTRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.GroupGetMemberListResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='proto.GroupGetMemberListResponse.Member.userId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.GroupGetMemberListResponse.Member.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adminRights', full_name='proto.GroupGetMemberListResponse.Member.adminRights', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memberRights', full_name='proto.GroupGetMemberListResponse.Member.memberRights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=672,
)

_GROUPGETMEMBERLISTRESPONSE = _descriptor.Descriptor(
  name='GroupGetMemberListResponse',
  full_name='proto.GroupGetMemberListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GroupGetMemberListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.GroupGetMemberListResponse.member', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPGETMEMBERLISTRESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=672,
)

_GROUPGETMEMBERLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GROUPGETMEMBERLIST.fields_by_name['filter_role'].enum_type = _GROUPGETMEMBERLIST_FILTERROLE
_GROUPGETMEMBERLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_GROUPGETMEMBERLIST_FILTERROLE.containing_type = _GROUPGETMEMBERLIST
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['adminRights'].message_type = GroupAddAdmin__pb2._GROUPADDADMIN_ADMINRIGHTS
_GROUPGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['memberRights'].message_type = GroupChangeMemberRights__pb2._GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
_GROUPGETMEMBERLISTRESPONSE_MEMBER.containing_type = _GROUPGETMEMBERLISTRESPONSE
_GROUPGETMEMBERLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GROUPGETMEMBERLISTRESPONSE.fields_by_name['member'].message_type = _GROUPGETMEMBERLISTRESPONSE_MEMBER
DESCRIPTOR.message_types_by_name['GroupGetMemberList'] = _GROUPGETMEMBERLIST
DESCRIPTOR.message_types_by_name['GroupGetMemberListResponse'] = _GROUPGETMEMBERLISTRESPONSE

GroupGetMemberList = _reflection.GeneratedProtocolMessageType('GroupGetMemberList', (_message.Message,), dict(
  DESCRIPTOR = _GROUPGETMEMBERLIST,
  __module__ = 'GroupGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupGetMemberList)
  ))
_sym_db.RegisterMessage(GroupGetMemberList)

GroupGetMemberListResponse = _reflection.GeneratedProtocolMessageType('GroupGetMemberListResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _GROUPGETMEMBERLISTRESPONSE_MEMBER,
    __module__ = 'GroupGetMemberList_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupGetMemberListResponse.Member)
    ))
  ,
  DESCRIPTOR = _GROUPGETMEMBERLISTRESPONSE,
  __module__ = 'GroupGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupGetMemberListResponse)
  ))
_sym_db.RegisterMessage(GroupGetMemberListResponse)
_sym_db.RegisterMessage(GroupGetMemberListResponse.Member)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoGroupGetMemberList'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelSendMessage.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelSendMessage.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43hannelSendMessage.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xff\x02\n\x12\x43hannelSendMessage\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12,\n\x0cmessage_type\x18\x02 \x01(\x0e\x32\x16.proto.RoomMessageType\x12\x0f\n\x07room_id\x18\x03 \x01(\x04\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x12\n\nattachment\x18\x05 \x01(\t\x12,\n\x08location\x18\x06 \x01(\x0b\x32\x1a.proto.RoomMessageLocation\x12*\n\x07\x63ontact\x18\x07 \x01(\x0b\x32\x19.proto.RoomMessageContact\x12\x10\n\x08reply_to\x18\x08 \x01(\x04\x12\x33\n\x0c\x66orward_from\x18\t \x01(\x0b\x32\x1d.proto.RoomMessageForwardFrom\x12\x11\n\trandom_id\x18\n \x01(\x04\x12\x17\n\x0f\x61\x64\x64itional_type\x18\x0b \x01(\r\x12\x17\n\x0f\x61\x64\x64itional_data\x18\x0c \x01(\t\"z\n\x1a\x43hannelSendMessageResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12(\n\x0croom_message\x18\x03 \x01(\x0b\x32\x12.proto.RoomMessageB)\n\x0enet.iGap.protoB\x17ProtoChannelSendMessageb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHANNELSENDMESSAGE = _descriptor.Descriptor(
  name='ChannelSendMessage',
  full_name='proto.ChannelSendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelSendMessage.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='proto.ChannelSendMessage.message_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelSendMessage.room_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.ChannelSendMessage.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='proto.ChannelSendMessage.attachment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='proto.ChannelSendMessage.location', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact', full_name='proto.ChannelSendMessage.contact', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='proto.ChannelSendMessage.reply_to', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forward_from', full_name='proto.ChannelSendMessage.forward_from', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_id', full_name='proto.ChannelSendMessage.random_id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_type', full_name='proto.ChannelSendMessage.additional_type', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_data', full_name='proto.ChannelSendMessage.additional_data', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=464,
)


_CHANNELSENDMESSAGERESPONSE = _descriptor.Descriptor(
  name='ChannelSendMessageResponse',
  full_name='proto.ChannelSendMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelSendMessageResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelSendMessageResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_message', full_name='proto.ChannelSendMessageResponse.room_message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=588,
)

_CHANNELSENDMESSAGE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELSENDMESSAGE.fields_by_name['message_type'].enum_type = Global__pb2._ROOMMESSAGETYPE
_CHANNELSENDMESSAGE.fields_by_name['location'].message_type = Global__pb2._ROOMMESSAGELOCATION
_CHANNELSENDMESSAGE.fields_by_name['contact'].message_type = Global__pb2._ROOMMESSAGECONTACT
_CHANNELSENDMESSAGE.fields_by_name['forward_from'].message_type = Global__pb2._ROOMMESSAGEFORWARDFROM
_CHANNELSENDMESSAGERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELSENDMESSAGERESPONSE.fields_by_name['room_message'].message_type = Global__pb2._ROOMMESSAGE
DESCRIPTOR.message_types_by_name['ChannelSendMessage'] = _CHANNELSENDMESSAGE
DESCRIPTOR.message_types_by_name['ChannelSendMessageResponse'] = _CHANNELSENDMESSAGERESPONSE

ChannelSendMessage = _reflection.GeneratedProtocolMessageType('ChannelSendMessage', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELSENDMESSAGE,
  __module__ = 'ChannelSendMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelSendMessage)
  ))
_sym_db.RegisterMessage(ChannelSendMessage)

ChannelSendMessageResponse = _reflection.GeneratedProtocolMessageType('ChannelSendMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELSENDMESSAGERESPONSE,
  __module__ = 'ChannelSendMessage_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelSendMessageResponse)
  ))
_sym_db.RegisterMessage(ChannelSendMessageResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoChannelSendMessage'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserContactsEdit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserContactsEdit.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16UserContactsEdit.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"i\n\x10UserContactsEdit\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05phone\x18\x02 \x01(\x04\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"\x85\x01\n\x18UserContactsEditResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05phone\x18\x02 \x01(\x04\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x10\n\x08initials\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoUserContactsEditb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERCONTACTSEDIT = _descriptor.Descriptor(
  name='UserContactsEdit',
  full_name='proto.UserContactsEdit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserContactsEdit.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsEdit.phone', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsEdit.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsEdit.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=169,
)


_USERCONTACTSEDITRESPONSE = _descriptor.Descriptor(
  name='UserContactsEditResponse',
  full_name='proto.UserContactsEditResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserContactsEditResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsEditResponse.phone', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsEditResponse.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsEditResponse.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initials', full_name='proto.UserContactsEditResponse.initials', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=305,
)

_USERCONTACTSEDIT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERCONTACTSEDITRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserContactsEdit'] = _USERCONTACTSEDIT
DESCRIPTOR.message_types_by_name['UserContactsEditResponse'] = _USERCONTACTSEDITRESPONSE

UserContactsEdit = _reflection.GeneratedProtocolMessageType('UserContactsEdit', (_message.Message,), dict(
  DESCRIPTOR = _USERCONTACTSEDIT,
  __module__ = 'UserContactsEdit_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsEdit)
  ))
_sym_db.RegisterMessage(UserContactsEdit)

UserContactsEditResponse = _reflection.GeneratedProtocolMessageType('UserContactsEditResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERCONTACTSEDITRESPONSE,
  __module__ = 'UserContactsEdit_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsEditResponse)
  ))
_sym_db.RegisterMessage(UserContactsEditResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoUserContactsEdit'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserIVandGetScore.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserIVandGetScore.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x17UserIVandGetScore.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"4\n\x11UserIVandGetScore\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xfc\x01\n\x19UserIVandGetScoreResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05score\x18\x02 \x01(\r\x12\x11\n\tuser_rank\x18\x03 \x01(\r\x12\x12\n\ntotal_rank\x18\x04 \x01(\r\x12;\n\x06scores\x18\x05 \x03(\x0b\x32+.proto.UserIVandGetScoreResponse.IVandScore\x1aI\n\nIVandScore\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0f\n\x07\x65n_name\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x61_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\rB(\n\x0enet.iGap.protoB\x16ProtoUserIVandGetScoreb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERIVANDGETSCORE = _descriptor.Descriptor(
  name='UserIVandGetScore',
  full_name='proto.UserIVandGetScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserIVandGetScore.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=117,
)


_USERIVANDGETSCORERESPONSE_IVANDSCORE = _descriptor.Descriptor(
  name='IVandScore',
  full_name='proto.UserIVandGetScoreResponse.IVandScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.UserIVandGetScoreResponse.IVandScore.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='en_name', full_name='proto.UserIVandGetScoreResponse.IVandScore.en_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fa_name', full_name='proto.UserIVandGetScoreResponse.IVandScore.fa_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.UserIVandGetScoreResponse.IVandScore.score', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=372,
)

_USERIVANDGETSCORERESPONSE = _descriptor.Descriptor(
  name='UserIVandGetScoreResponse',
  full_name='proto.UserIVandGetScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserIVandGetScoreResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.UserIVandGetScoreResponse.score', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_rank', full_name='proto.UserIVandGetScoreResponse.user_rank', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_rank', full_name='proto.UserIVandGetScoreResponse.total_rank', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scores', full_name='proto.UserIVandGetScoreResponse.scores', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERIVANDGETSCORERESPONSE_IVANDSCORE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=372,
)

_USERIVANDGETSCORE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERIVANDGETSCORERESPONSE_IVANDSCORE.containing_type = _USERIVANDGETSCORERESPONSE
_USERIVANDGETSCORERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERIVANDGETSCORERESPONSE.fields_by_name['scores'].message_type = _USERIVANDGETSCORERESPONSE_IVANDSCORE
DESCRIPTOR.message_types_by_name['UserIVandGetScore'] = _USERIVANDGETSCORE
DESCRIPTOR.message_types_by_name['UserIVandGetScoreResponse'] = _USERIVANDGETSCORERESPONSE

UserIVandGetScore = _reflection.GeneratedProtocolMessageType('UserIVandGetScore', (_message.Message,), dict(
  DESCRIPTOR = _USERIVANDGETSCORE,
  __module__ = 'UserIVandGetScore_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserIVandGetScore)
  ))
_sym_db.RegisterMessage(UserIVandGetScore)

UserIVandGetScoreResponse = _reflection.GeneratedProtocolMessageType('UserIVandGetScoreResponse', (_message.Message,), dict(

  IVandScore = _reflection.GeneratedProtocolMessageType('IVandScore', (_message.Message,), dict(
    DESCRIPTOR = _USERIVANDGETSCORERESPONSE_IVANDSCORE,
    __module__ = 'UserIVandGetScore_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserIVandGetScoreResponse.IVandScore)
    ))
  ,
  DESCRIPTOR = _USERIVANDGETSCORERESPONSE,
  __module__ = 'UserIVandGetScore_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserIVandGetScoreResponse)
  ))
_sym_db.RegisterMessage(UserIVandGetScoreResponse)
_sym_db.RegisterMessage(UserIVandGetScoreResponse.IVandScore)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\026ProtoUserIVandGetScore'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: QrCodeAddContact.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='QrCodeAddContact.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16QrCodeAddContact.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"i\n\x10QrCodeAddContact\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\r\n\x05phone\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"T\n\x18QrCodeAddContactResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x15\n\rqr_code_image\x18\x02 \x01(\x0c\x42\'\n\x0enet.iGap.protoB\x15ProtoQrCodeAddContactb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_QRCODEADDCONTACT = _descriptor.Descriptor(
  name='QrCodeAddContact',
  full_name='proto.QrCodeAddContact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.QrCodeAddContact.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.QrCodeAddContact.phone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.QrCodeAddContact.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.QrCodeAddContact.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=169,
)


_QRCODEADDCONTACTRESPONSE = _descriptor.Descriptor(
  name='QrCodeAddContactResponse',
  full_name='proto.QrCodeAddContactResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.QrCodeAddContactResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qr_code_image', full_name='proto.QrCodeAddContactResponse.qr_code_image', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=255,
)

_QRCODEADDCONTACT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_QRCODEADDCONTACTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['QrCodeAddContact'] = _QRCODEADDCONTACT
DESCRIPTOR.message_types_by_name['QrCodeAddContactResponse'] = _QRCODEADDCONTACTRESPONSE

QrCodeAddContact = _reflection.GeneratedProtocolMessageType('QrCodeAddContact', (_message.Message,), dict(
  DESCRIPTOR = _QRCODEADDCONTACT,
  __module__ = 'QrCodeAddContact_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeAddContact)
  ))
_sym_db.RegisterMessage(QrCodeAddContact)

QrCodeAddContactResponse = _reflection.GeneratedProtocolMessageType('QrCodeAddContactResponse', (_message.Message,), dict(
  DESCRIPTOR = _QRCODEADDCONTACTRESPONSE,
  __module__ = 'QrCodeAddContact_pb2'
  # @@protoc_insertion_point(class_scope:proto.QrCodeAddContactResponse)
  ))
_sym_db.RegisterMessage(QrCodeAddContactResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoQrCodeAddContact'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingGetLog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import SignalingOffer_pb2 as SignalingOffer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingGetLog.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15SignalingGetLog.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x14SignalingOffer.proto\"\xd1\x01\n\x0fSignalingGetLog\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\npagination\x18\x02 \x01(\x0b\x32\x11.proto.Pagination\x12-\n\x06\x66ilter\x18\x03 \x01(\x0e\x32\x1d.proto.SignalingGetLog.Filter\"G\n\x06\x46ilter\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MISSED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0c\n\x08INCOMING\x10\x03\x12\x0c\n\x08OUTGOING\x10\x04\"\xa6\x03\n\x17SignalingGetLogResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x42\n\rsignaling_log\x18\x02 \x03(\x0b\x32+.proto.SignalingGetLogResponse.SignalingLog\x1a\xa3\x02\n\x0cSignalingLog\x12\n\n\x02id\x18\x01 \x01(\x04\x12(\n\x04type\x18\x02 \x01(\x0e\x32\x1a.proto.SignalingOffer.Type\x12\x42\n\x06status\x18\x03 \x01(\x0e\x32\x32.proto.SignalingGetLogResponse.SignalingLog.Status\x12#\n\x04peer\x18\x04 \x01(\x0b\x32\x15.proto.RegisteredUser\x12\x12\n\noffer_time\x18\x05 \x01(\r\x12\x10\n\x08\x64uration\x18\x06 \x01(\r\x12\x0e\n\x06log_id\x18\x07 \x01(\x04\">\n\x06Status\x12\n\n\x06MISSED\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0c\n\x08INCOMING\x10\x02\x12\x0c\n\x08OUTGOING\x10\x03\x42&\n\x0enet.iGap.protoB\x14ProtoSignalingGetLogb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,SignalingOffer__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGGETLOG_FILTER = _descriptor.EnumDescriptor(
  name='Filter',
  full_name='proto.SignalingGetLog.Filter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMING', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTGOING', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=238,
  serialized_end=309,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGGETLOG_FILTER)

_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.SignalingGetLogResponse.SignalingLog.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTGOING', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=672,
  serialized_end=734,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS)


_SIGNALINGGETLOG = _descriptor.Descriptor(
  name='SignalingGetLog',
  full_name='proto.SignalingGetLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingGetLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.SignalingGetLog.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='proto.SignalingGetLog.filter', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGGETLOG_FILTER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=309,
)


_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG = _descriptor.Descriptor(
  name='SignalingLog',
  full_name='proto.SignalingGetLogResponse.SignalingLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.SignalingGetLogResponse.SignalingLog.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingGetLogResponse.SignalingLog.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.SignalingGetLogResponse.SignalingLog.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer', full_name='proto.SignalingGetLogResponse.SignalingLog.peer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offer_time', full_name='proto.SignalingGetLogResponse.SignalingLog.offer_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='proto.SignalingGetLogResponse.SignalingLog.duration', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log_id', full_name='proto.SignalingGetLogResponse.SignalingLog.log_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=734,
)

_SIGNALINGGETLOGRESPONSE = _descriptor.Descriptor(
  name='SignalingGetLogResponse',
  full_name='proto.SignalingGetLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingGetLogResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signaling_log', full_name='proto.SignalingGetLogResponse.signaling_log', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=734,
)

_SIGNALINGGETLOG.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGGETLOG.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_SIGNALINGGETLOG.fields_by_name['filter'].enum_type = _SIGNALINGGETLOG_FILTER
_SIGNALINGGETLOG_FILTER.containing_type = _SIGNALINGGETLOG
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['type'].enum_type = SignalingOffer__pb2._SIGNALINGOFFER_TYPE
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['status'].enum_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.fields_by_name['peer'].message_type = Global__pb2._REGISTEREDUSER
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG.containing_type = _SIGNALINGGETLOGRESPONSE
_SIGNALINGGETLOGRESPONSE_SIGNALINGLOG_STATUS.containing_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG
_SIGNALINGGETLOGRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGGETLOGRESPONSE.fields_by_name['signaling_log'].message_type = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG
DESCRIPTOR.message_types_by_name['SignalingGetLog'] = _SIGNALINGGETLOG
DESCRIPTOR.message_types_by_name['SignalingGetLogResponse'] = _SIGNALINGGETLOGRESPONSE

SignalingGetLog = _reflection.GeneratedProtocolMessageType('SignalingGetLog', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGGETLOG,
  __module__ = 'SignalingGetLog_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetLog)
  ))
_sym_db.RegisterMessage(SignalingGetLog)

SignalingGetLogResponse = _reflection.GeneratedProtocolMessageType('SignalingGetLogResponse', (_message.Message,), dict(

  SignalingLog = _reflection.GeneratedProtocolMessageType('SignalingLog', (_message.Message,), dict(
    DESCRIPTOR = _SIGNALINGGETLOGRESPONSE_SIGNALINGLOG,
    __module__ = 'SignalingGetLog_pb2'
    # @@protoc_insertion_point(class_scope:proto.SignalingGetLogResponse.SignalingLog)
    ))
  ,
  DESCRIPTOR = _SIGNALINGGETLOGRESPONSE,
  __module__ = 'SignalingGetLog_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingGetLogResponse)
  ))
_sym_db.RegisterMessage(SignalingGetLogResponse)
_sym_db.RegisterMessage(SignalingGetLogResponse.SignalingLog)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoSignalingGetLog'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplSalesList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplSalesList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12MplSalesList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"}\n\x0cMplSalesList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x15.proto.MplSale.Status\x12%\n\npagination\x18\x03 \x01(\x0b\x32\x11.proto.Pagination\"W\n\x14MplSalesListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x1c\n\x04sale\x18\x02 \x03(\x0b\x32\x0e.proto.MplSaleB#\n\x0enet.iGap.protoB\x11ProtoMplSalesListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLSALESLIST = _descriptor.Descriptor(
  name='MplSalesList',
  full_name='proto.MplSalesList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplSalesList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplSalesList.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.MplSalesList.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=199,
)


_MPLSALESLISTRESPONSE = _descriptor.Descriptor(
  name='MplSalesListResponse',
  full_name='proto.MplSalesListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplSalesListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sale', full_name='proto.MplSalesListResponse.sale', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=288,
)

_MPLSALESLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLSALESLIST.fields_by_name['status'].enum_type = Global__pb2._MPLSALE_STATUS
_MPLSALESLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_MPLSALESLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_MPLSALESLISTRESPONSE.fields_by_name['sale'].message_type = Global__pb2._MPLSALE
DESCRIPTOR.message_types_by_name['MplSalesList'] = _MPLSALESLIST
DESCRIPTOR.message_types_by_name['MplSalesListResponse'] = _MPLSALESLISTRESPONSE

MplSalesList = _reflection.GeneratedProtocolMessageType('MplSalesList', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESLIST,
  __module__ = 'MplSalesList_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesList)
  ))
_sym_db.RegisterMessage(MplSalesList)

MplSalesListResponse = _reflection.GeneratedProtocolMessageType('MplSalesListResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESLISTRESPONSE,
  __module__ = 'MplSalesList_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesListResponse)
  ))
_sym_db.RegisterMessage(MplSalesListResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoMplSalesList'))
# @@protoc_insertion_point(module_scope)



from typing import TYPE_CHECKING
import json
if TYPE_CHECKING:
    from client import BotClient

from dataclasses import dataclass

PRIVATE_ACTION_IDS = [str(i) for i in range(200, 210)] + [str(i) for i in range(30200, 30210)]
GROUP_ACTION_IDS = [str(i) for i in range(300, 329)] + [str(i) for i in range(30300, 30329)]
CHANNEL_ACTION_IDS = [str(i) for i in range(400, 427)] + [str(i) for i in range(30400, 30427)]

@dataclass
class User:
    data: dict

    @property
    def user_id(self) -> int | None:
        value = self.data.get("userId")
        return int(value) if value is not None else None

    @property
    def cache_id(self) -> str | None:
        return self.data.get("cacheId")


@dataclass
class Author:
    data: dict

    @property
    def hash(self) -> str | None:
        return self.data.get("hash")

    @property
    def user(self) -> User:
        return User(self.data.get("user", {}))


@dataclass
class RoomMessage:
    data: dict

    @property
    def message_id(self) -> int | None:
        value = self.data.get("messageId")
        return value if value is not None else None

    @property
    def message_version(self) -> int | None:
        value = self.data.get("messageVersion")
        return value if value is not None else None

    @property
    def status(self) -> str | None:
        return self.data.get("status")

    @property
    def status_version(self) -> int | None:
        value = self.data.get("statusVersion")
        return value if value is not None else None

    @property
    def message(self) -> str | None:
        return self.data.get("message")

    @property
    def author(self) -> Author:
        return Author(self.data.get("author", {}))

    @property
    def create_time(self) -> int | None:
        return self.data.get("createTime")

    @property
    def update_time(self) -> int | None:
        return self.data.get("updateTime")

    @property
    def random_id(self) -> int | None:
        value = self.data.get("randomId")
        return value if value is not None else None
    
    @property
    def reply_to(self) -> "RoomMessage | None":
        """اگر پیام دارای replyTo باشد، آن را به صورت RoomMessage برگردان"""
        reply_data = self.data.get("replyTo")
        if reply_data:
            return RoomMessage(reply_data)
        return None


class Message:
    def __init__(self, client: "BotClient", update: dict):
        self.client = client
        self.update = update

        self.room_id = int(update.get("roomId")) if update.get("roomId") else None
        self.room_message = RoomMessage(update.get("roomMessage", {}))
        self.action_id = update.get("actionId", "666 6666 666 333")

    # میان‌برهای سطح بالا
    @property
    def text(self) -> str | None:
        return self.room_message.message

    @property
    def random_id(self) -> int | None:
        return self.room_message.random_id

    @property
    def user_id(self) -> int | None:
        return self.room_message.author.user.user_id
    
    def __str__(self) -> str:
        """نمایش خوانای update"""
        return json.dumps(self.update, ensure_ascii=False, indent=2)
    
    def __getitem__(self, key):
        return self.update[key]

    def __repr__(self) -> str:
        """نمایش دقیق‌تر برای دیباگ"""
        return f"<Message update={self.update}>"
    
    async def reply_message(self, text: str, room_id: int=None, reply_to_message_id: int | None = None):
        if self.action_id in PRIVATE_ACTION_IDS:
            return await self.client.send_message(room_id or self.room_id, text, reply_to_message_id  or self.room_message.message_id, target_type="private")
        elif self.action_id in GROUP_ACTION_IDS:
            return await self.client.send_message(room_id or self.room_id, text, reply_to_message_id or self.room_message.message_id, target_type="group")
        elif self.action_id in CHANNEL_ACTION_IDS:
            return await self.client.send_message(room_id or self.room_id, text, reply_to_message_id or self.room_message.message_id, target_type="channel")
    
    async def delete_message(self, room_id: int=None, message_id: int=None, delete_type: str = "Global"):
        if self.action_id in PRIVATE_ACTION_IDS:
            return await self.client.delete_message(room_id or self.room_id, message_id or self.room_message.message_id, delete_type, "private")
        elif self.action_id in GROUP_ACTION_IDS:
            return await self.client.delete_message(room_id or self.room_id, message_id or self.room_message.message_id, "group")
        elif self.action_id in CHANNEL_ACTION_IDS:
            return await self.client.delete_message(room_id or self.room_id, message_id or self.room_message.message_id, "channel")
    
    async def ban_member(self, room_id, member_id):
        if self.action_id in GROUP_ACTION_IDS:
            return await self.client.ban_member(room_id, member_id, "group")

    async def reply_message_private(self, text: str, reply_to_message_id: int | None = None):
        return await self.client.send_message(self.room_id, text, reply_to_message_id  or self.room_message.message_id, "private")
    
    async def delete_message_private(self, message_id: int=None, delete_type="Global"):
        return await self.client.delete_message(self.room_id, message_id or self.room_message.message_id, delete_type, "private")

    async def reply_message_group(self, text: str, reply_to_message_id: int | None = None):
        return await self.client.send_message(self.room_id, text, reply_to_message_id or self.room_message.message_id, "group")
    
    async def delete_message_group(self, message_id: int=None):
        return await self.client.delete_message(self.room_id, message_id or self.room_message.message_id, target_type="group")
    
    async def ban_member_group(self, room_id, member_id):
        return await self.client.ban_member(room_id, member_id, "group")
    
    async def reply_message_channel(self, text: str, reply_to_message_id: int | None = None):
        return await self.client.send_message(self.room_id, text, reply_to_message_id or self.room_message.message_id, "channel")
    
    async def delete_message_channel(self, message_id: int=None):
        return await self.client.delete_message(self.room_id, message_id or self.room_message.message_id, target_type="channel")


# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingLeave.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingLeave.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14SignalingLeave.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"1\n\x0eSignalingLeave\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xee\x01\n\x16SignalingLeaveResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".proto.SignalingLeaveResponse.Type\"\x7f\n\x04Type\x12\n\n\x06MISSED\x10\x00\x12\x0c\n\x08REJECTED\x10\x01\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x02\x12\x10\n\x0cNOT_ANSWERED\x10\x03\x12\x0f\n\x0bUNAVAILABLE\x10\x04\x12\x10\n\x0c\x44ISCONNECTED\x10\x05\x12\x0c\n\x08\x46INISHED\x10\x06\x12\x0c\n\x08TOO_LONG\x10\x07\x42%\n\x0enet.iGap.protoB\x13ProtoSignalingLeaveb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SIGNALINGLEAVERESPONSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.SignalingLeaveResponse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MISSED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ANSWERED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_LONG', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=225,
  serialized_end=352,
)
_sym_db.RegisterEnumDescriptor(_SIGNALINGLEAVERESPONSE_TYPE)


_SIGNALINGLEAVE = _descriptor.Descriptor(
  name='SignalingLeave',
  full_name='proto.SignalingLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingLeave.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=111,
)


_SIGNALINGLEAVERESPONSE = _descriptor.Descriptor(
  name='SignalingLeaveResponse',
  full_name='proto.SignalingLeaveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingLeaveResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.SignalingLeaveResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNALINGLEAVERESPONSE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=352,
)

_SIGNALINGLEAVE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGLEAVERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_SIGNALINGLEAVERESPONSE.fields_by_name['type'].enum_type = _SIGNALINGLEAVERESPONSE_TYPE
_SIGNALINGLEAVERESPONSE_TYPE.containing_type = _SIGNALINGLEAVERESPONSE
DESCRIPTOR.message_types_by_name['SignalingLeave'] = _SIGNALINGLEAVE
DESCRIPTOR.message_types_by_name['SignalingLeaveResponse'] = _SIGNALINGLEAVERESPONSE

SignalingLeave = _reflection.GeneratedProtocolMessageType('SignalingLeave', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGLEAVE,
  __module__ = 'SignalingLeave_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingLeave)
  ))
_sym_db.RegisterMessage(SignalingLeave)

SignalingLeaveResponse = _reflection.GeneratedProtocolMessageType('SignalingLeaveResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGLEAVERESPONSE,
  __module__ = 'SignalingLeave_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingLeaveResponse)
  ))
_sym_db.RegisterMessage(SignalingLeaveResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoSignalingLeave'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetSalesToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetSalesToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16MplGetSalesToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x95\x01\n\x10MplGetSalesToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04\x12\x12\n\nto_user_id\x18\x03 \x01(\x04\x12\x16\n\x0einvoice_number\x18\x04 \x01(\x04\x12\x0f\n\x07inquiry\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\x82\x01\n\x18MplGetSalesTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoMplGetSalesTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLGETSALESTOKEN = _descriptor.Descriptor(
  name='MplGetSalesToken',
  full_name='proto.MplGetSalesToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetSalesToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.MplGetSalesToken.amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.MplGetSalesToken.to_user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.MplGetSalesToken.invoice_number', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inquiry', full_name='proto.MplGetSalesToken.inquiry', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.MplGetSalesToken.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=214,
)


_MPLGETSALESTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetSalesTokenResponse',
  full_name='proto.MplGetSalesTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetSalesTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetSalesTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetSalesTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetSalesTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetSalesTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=347,
)

_MPLGETSALESTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETSALESTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetSalesToken'] = _MPLGETSALESTOKEN
DESCRIPTOR.message_types_by_name['MplGetSalesTokenResponse'] = _MPLGETSALESTOKENRESPONSE

MplGetSalesToken = _reflection.GeneratedProtocolMessageType('MplGetSalesToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETSALESTOKEN,
  __module__ = 'MplGetSalesToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetSalesToken)
  ))
_sym_db.RegisterMessage(MplGetSalesToken)

MplGetSalesTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetSalesTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETSALESTOKENRESPONSE,
  __module__ = 'MplGetSalesToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetSalesTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetSalesTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoMplGetSalesToken'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatConvertToGroup.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChatConvertToGroup.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18\x43hatConvertToGroup.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"i\n\x12\x43hatConvertToGroup\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x98\x01\n\x1a\x43hatConvertToGroupResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12#\n\x04role\x18\x05 \x01(\x0e\x32\x15.proto.GroupRoom.RoleB)\n\x0enet.iGap.protoB\x17ProtoChatConvertToGroupb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CHATCONVERTTOGROUP = _descriptor.Descriptor(
  name='ChatConvertToGroup',
  full_name='proto.ChatConvertToGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChatConvertToGroup.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatConvertToGroup.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.ChatConvertToGroup.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ChatConvertToGroup.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=185,
)


_CHATCONVERTTOGROUPRESPONSE = _descriptor.Descriptor(
  name='ChatConvertToGroupResponse',
  full_name='proto.ChatConvertToGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChatConvertToGroupResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChatConvertToGroupResponse.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.ChatConvertToGroupResponse.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ChatConvertToGroupResponse.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.ChatConvertToGroupResponse.role', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=340,
)

_CHATCONVERTTOGROUP.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHATCONVERTTOGROUPRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHATCONVERTTOGROUPRESPONSE.fields_by_name['role'].enum_type = Global__pb2._GROUPROOM_ROLE
DESCRIPTOR.message_types_by_name['ChatConvertToGroup'] = _CHATCONVERTTOGROUP
DESCRIPTOR.message_types_by_name['ChatConvertToGroupResponse'] = _CHATCONVERTTOGROUPRESPONSE

ChatConvertToGroup = _reflection.GeneratedProtocolMessageType('ChatConvertToGroup', (_message.Message,), dict(
  DESCRIPTOR = _CHATCONVERTTOGROUP,
  __module__ = 'ChatConvertToGroup_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatConvertToGroup)
  ))
_sym_db.RegisterMessage(ChatConvertToGroup)

ChatConvertToGroupResponse = _reflection.GeneratedProtocolMessageType('ChatConvertToGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHATCONVERTTOGROUPRESPONSE,
  __module__ = 'ChatConvertToGroup_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatConvertToGroupResponse)
  ))
_sym_db.RegisterMessage(ChatConvertToGroupResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoChatConvertToGroup'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserContactsImport.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserContactsImport.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18UserContactsImport.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xe3\x01\n\x12UserContactsImport\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x33\n\x08\x63ontacts\x18\x02 \x03(\x0b\x32!.proto.UserContactsImport.Contact\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x14\n\x0c\x63ontact_hash\x18\x04 \x01(\t\x1aR\n\x07\x43ontact\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\"\xb6\x01\n\x1aUserContactsImportResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x46\n\x13registered_contacts\x18\x02 \x03(\x0b\x32).proto.UserContactsImportResponse.Contact\x1a-\n\x07\x43ontact\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x42)\n\x0enet.iGap.protoB\x17ProtoUserContactsImportb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERCONTACTSIMPORT_CONTACT = _descriptor.Descriptor(
  name='Contact',
  full_name='proto.UserContactsImport.Contact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.UserContactsImport.Contact.phone', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.UserContactsImport.Contact.first_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.UserContactsImport.Contact.last_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='proto.UserContactsImport.Contact.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=294,
)

_USERCONTACTSIMPORT = _descriptor.Descriptor(
  name='UserContactsImport',
  full_name='proto.UserContactsImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserContactsImport.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contacts', full_name='proto.UserContactsImport.contacts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='force', full_name='proto.UserContactsImport.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact_hash', full_name='proto.UserContactsImport.contact_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERCONTACTSIMPORT_CONTACT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=294,
)


_USERCONTACTSIMPORTRESPONSE_CONTACT = _descriptor.Descriptor(
  name='Contact',
  full_name='proto.UserContactsImportResponse.Contact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='proto.UserContactsImportResponse.Contact.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserContactsImportResponse.Contact.user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=479,
)

_USERCONTACTSIMPORTRESPONSE = _descriptor.Descriptor(
  name='UserContactsImportResponse',
  full_name='proto.UserContactsImportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserContactsImportResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registered_contacts', full_name='proto.UserContactsImportResponse.registered_contacts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_USERCONTACTSIMPORTRESPONSE_CONTACT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=479,
)

_USERCONTACTSIMPORT_CONTACT.containing_type = _USERCONTACTSIMPORT
_USERCONTACTSIMPORT.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERCONTACTSIMPORT.fields_by_name['contacts'].message_type = _USERCONTACTSIMPORT_CONTACT
_USERCONTACTSIMPORTRESPONSE_CONTACT.containing_type = _USERCONTACTSIMPORTRESPONSE
_USERCONTACTSIMPORTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERCONTACTSIMPORTRESPONSE.fields_by_name['registered_contacts'].message_type = _USERCONTACTSIMPORTRESPONSE_CONTACT
DESCRIPTOR.message_types_by_name['UserContactsImport'] = _USERCONTACTSIMPORT
DESCRIPTOR.message_types_by_name['UserContactsImportResponse'] = _USERCONTACTSIMPORTRESPONSE

UserContactsImport = _reflection.GeneratedProtocolMessageType('UserContactsImport', (_message.Message,), dict(

  Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), dict(
    DESCRIPTOR = _USERCONTACTSIMPORT_CONTACT,
    __module__ = 'UserContactsImport_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserContactsImport.Contact)
    ))
  ,
  DESCRIPTOR = _USERCONTACTSIMPORT,
  __module__ = 'UserContactsImport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsImport)
  ))
_sym_db.RegisterMessage(UserContactsImport)
_sym_db.RegisterMessage(UserContactsImport.Contact)

UserContactsImportResponse = _reflection.GeneratedProtocolMessageType('UserContactsImportResponse', (_message.Message,), dict(

  Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), dict(
    DESCRIPTOR = _USERCONTACTSIMPORTRESPONSE_CONTACT,
    __module__ = 'UserContactsImport_pb2'
    # @@protoc_insertion_point(class_scope:proto.UserContactsImportResponse.Contact)
    ))
  ,
  DESCRIPTOR = _USERCONTACTSIMPORTRESPONSE,
  __module__ = 'UserContactsImport_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserContactsImportResponse)
  ))
_sym_db.RegisterMessage(UserContactsImportResponse)
_sym_db.RegisterMessage(UserContactsImportResponse.Contact)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoUserContactsImport'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplSalesConfirm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplSalesConfirm.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x15MplSalesConfirm.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xa0\x01\n\x0fMplSalesConfirm\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x16\n\x0einvoice_number\x18\x02 \x01(\x04\x12/\n\x07\x63onfirm\x18\x03 \x01(\x0e\x32\x1e.proto.MplSalesConfirm.Confirm\"#\n\x07\x43onfirm\x12\x0b\n\x07\x43ONFIRM\x10\x00\x12\x0b\n\x07REVERSE\x10\x01\"Z\n\x17MplSalesConfirmResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x1c\n\x04sale\x18\x02 \x01(\x0b\x32\x0e.proto.MplSaleB&\n\x0enet.iGap.protoB\x14ProtoMplSalesConfirmb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_MPLSALESCONFIRM_CONFIRM = _descriptor.EnumDescriptor(
  name='Confirm',
  full_name='proto.MplSalesConfirm.Confirm',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIRM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVERSE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=203,
  serialized_end=238,
)
_sym_db.RegisterEnumDescriptor(_MPLSALESCONFIRM_CONFIRM)


_MPLSALESCONFIRM = _descriptor.Descriptor(
  name='MplSalesConfirm',
  full_name='proto.MplSalesConfirm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplSalesConfirm.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.MplSalesConfirm.invoice_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confirm', full_name='proto.MplSalesConfirm.confirm', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MPLSALESCONFIRM_CONFIRM,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=238,
)


_MPLSALESCONFIRMRESPONSE = _descriptor.Descriptor(
  name='MplSalesConfirmResponse',
  full_name='proto.MplSalesConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplSalesConfirmResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sale', full_name='proto.MplSalesConfirmResponse.sale', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=330,
)

_MPLSALESCONFIRM.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLSALESCONFIRM.fields_by_name['confirm'].enum_type = _MPLSALESCONFIRM_CONFIRM
_MPLSALESCONFIRM_CONFIRM.containing_type = _MPLSALESCONFIRM
_MPLSALESCONFIRMRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_MPLSALESCONFIRMRESPONSE.fields_by_name['sale'].message_type = Global__pb2._MPLSALE
DESCRIPTOR.message_types_by_name['MplSalesConfirm'] = _MPLSALESCONFIRM
DESCRIPTOR.message_types_by_name['MplSalesConfirmResponse'] = _MPLSALESCONFIRMRESPONSE

MplSalesConfirm = _reflection.GeneratedProtocolMessageType('MplSalesConfirm', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESCONFIRM,
  __module__ = 'MplSalesConfirm_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesConfirm)
  ))
_sym_db.RegisterMessage(MplSalesConfirm)

MplSalesConfirmResponse = _reflection.GeneratedProtocolMessageType('MplSalesConfirmResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALESCONFIRMRESPONSE,
  __module__ = 'MplSalesConfirm_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSalesConfirmResponse)
  ))
_sym_db.RegisterMessage(MplSalesConfirmResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\024ProtoMplSalesConfirm'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FileUploadOption.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FileUploadOption.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16\x46ileUploadOption.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"A\n\x10\x46ileUploadOption\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0c\n\x04size\x18\x02 \x01(\x03\"\x8a\x01\n\x18\x46ileUploadOptionResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x19\n\x11\x66irst_bytes_limit\x18\x02 \x01(\x05\x12\x18\n\x10last_bytes_limit\x18\x03 \x01(\x05\x12\x16\n\x0emax_connection\x18\x04 \x01(\x05\x42\'\n\x0enet.iGap.protoB\x15ProtoFileUploadOptionb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_FILEUPLOADOPTION = _descriptor.Descriptor(
  name='FileUploadOption',
  full_name='proto.FileUploadOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FileUploadOption.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.FileUploadOption.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=129,
)


_FILEUPLOADOPTIONRESPONSE = _descriptor.Descriptor(
  name='FileUploadOptionResponse',
  full_name='proto.FileUploadOptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FileUploadOptionResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_bytes_limit', full_name='proto.FileUploadOptionResponse.first_bytes_limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_bytes_limit', full_name='proto.FileUploadOptionResponse.last_bytes_limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_connection', full_name='proto.FileUploadOptionResponse.max_connection', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=270,
)

_FILEUPLOADOPTION.fields_by_name['request'].message_type = Request__pb2._REQUEST
_FILEUPLOADOPTIONRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['FileUploadOption'] = _FILEUPLOADOPTION
DESCRIPTOR.message_types_by_name['FileUploadOptionResponse'] = _FILEUPLOADOPTIONRESPONSE

FileUploadOption = _reflection.GeneratedProtocolMessageType('FileUploadOption', (_message.Message,), dict(
  DESCRIPTOR = _FILEUPLOADOPTION,
  __module__ = 'FileUploadOption_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileUploadOption)
  ))
_sym_db.RegisterMessage(FileUploadOption)

FileUploadOptionResponse = _reflection.GeneratedProtocolMessageType('FileUploadOptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _FILEUPLOADOPTIONRESPONSE,
  __module__ = 'FileUploadOption_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileUploadOptionResponse)
  ))
_sym_db.RegisterMessage(FileUploadOptionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoFileUploadOption'))
# @@protoc_insertion_point(module_scope)
